clear variables;
% working area dimensions in mm ( minus the missing diameter of the 6mm bit
% to cut a 12mm hole)
wX = 394;
wY = 344;

plotPadding = 20;

% max multiples for optimal spacing sets
S = [3, 6, 9, 13, 17, 23];
SSet = {
    [0, 1, 3]; 
    [0, 1, 4, 6];
    [0, 1, 4, 7, 9];
    [0, 1, 4, 5, 11, 13];
    [0, 1, 4, 10, 12, 15, 17];
    [0, 1, 4, 10, 16, 18, 21, 23]
    };

% dimensions of the clamps to be used
minReach = 3; % the minimal distance from the center of the threaded insert - which is used to fix the clamp - to the stock, such that the clamp can tightly grip the stock.
maxReach = 33; % the maximal distance " " " " 

% spacing is twice the clamp range, because each clamp only has to cover
% half of the space between to spacing-units
% maxReach can be multiplied by sqrt(2)/2 to account for diagonal clamping
% direction
spacing = 2 * (maxReach * sqrt(2) / 2 - minReach);

% find the maximal multiple of the spacing-unit (clamp range) that fits the working area
fX = wX / spacing;
fY = wY / spacing;

% natural numbers are required so that the first multiple (zero) and last
% multiple of the spacing unit are on the edges of the working area.
% these numbers are taken from the set of available maximal multipliers
fX = min(S(S > fX));
fY = min(S(S > fY));

% calculate the spacing-unit for X and Y
uX = wX / fX;
uY = wY / fY;

assert(uX < spacing, "Required clamp range is larger than available clamp range on X axis.");
assert(uY < spacing, "Required clamp range is larger than available clamp range on Y axis.");

fprintf("Required spacing on X axis is '%.3f mm' ('%.3f mm' per clamp), with a maximal multiple of '%.3f units' to cover the X working area of '%.3f mm'\n", uX, uX/2, fX, uX * fX);
fprintf("Required spacing on Y axis is '%.3f mm' ('%.3f mm' per clamp), with a maximal multiple of '%.3f units' to cover the Y working area of '%.3f mm'\n", uY, uY/2, fY, uY * fY);

% find the spacing set for X and Y
sX = SSet{S == fX};
sY = SSet{S == fY};

fprintf("Spacing set for x-axis:\n");
disp(sX);
fprintf("Spacing set for y-axis:\n");
disp(sY);

% plot the clamp insert locations
[XX, YY] = meshgrid(sX * uX, sY * uY);
plot(XX(:), YY(:), "o");
axis equal
axis([-plotPadding wX + plotPadding -plotPadding wY + plotPadding])
grid on
xticks(sX * uX);
yticks(sY * uY);
